#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.ghostwhitecrab.com/generator/
# source           : http://www.ghostwhitecrab.com/generator/generator-0.35-cbiere-r3.tar.bz2

# Package name
NAME="generator"
# Package version
VERSION="0.35"
# Sub-version
SUBVERSION="cbiere-r3"
# Source code URL
SOURCE="http://www.ghostwhitecrab.com/generator/generator-$VERSION-cbiere-r3.tar.bz2"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --with-raze --with-sdl-audio --with-sdl"
# Files that should be placed in /usr/doc/package-version/
DOCS="docs AUTHORS COPYING ChangeLog INSTALL LICENSE NEWS README TODO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: generators - a Sega Genesis/Mega Drive console emulator
$NAME:
$NAME: Generator is an open source emulator designed to emulate the Sega 
$NAME: Genesis/Mega Drive console, a popular games machine produced in the
$NAME: early 1990s.
$NAME: 
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION-$SUBVERSION
if [ -f $NAME-$VERSION-$SUBVERSION.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvjf $NAME-$VERSION-$SUBVERSION.tar.bz2
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Generator
Exec=generator
Terminal=false
Type=Application
Categories=Game;Emulator
Icon=generator
EOF

# Configure and make
cd $NAME-$VERSION-$SUBVERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's/-O3//' configure
./configure $CONFIGOPTIONS
make

# Install on temporary directory
make install DESTDIR=$PKG

# Create a launch script
cat > $PKG/usr/bin/generator << EOF
#!/bin/sh

FILE=\`Xdialog --title "Please choose a Sega Mega Drive/Genesis ROM file" --screen-center --fselect /home 35 80 2>&1\`

case \$? in
	0)
		generator-sdl -a "\$FILE";;
	1)
		echo "Exiting.";;
	255)
		echo "Exiting.";;
esac
EOF
chmod a+x $PKG/usr/bin/generator

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy icons to the right place
ICONSIZES="64 48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION-$SUBVERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
chmod a+r,a+x $PKG/usr/doc/$NAME-$VERSION/docs/
cat > $PKG/usr/doc/$NAME-$VERSION/keys.txt << EOF
Key assignments:
===================================
A: A
B: S
C: D
UP: <Arrow Up>
DOWN: <Arrow Down>
LEFT: <Arrow Left>
RIGHT: <Arrow Right>
Play/Pause: <Pause> or <Control> + P
Soft Reset: <Control> + R
Hard Reset: <Control> + <Shift> + R
Quit: <Control> + Q
Fullscreen toggle: <Control> + F
Window 100%: <Control> + 1
Window 200%: <Control> + 2
EOF

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION-$SUBVERSION
rm -rf $PKG
